package cn.rankin.cmsweb.service.product;

import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.data.api.product.dto.CourseDTO;
import cn.rankin.data.api.product.dto.PackageDTO;
import cn.rankin.data.api.product.dto.SupportDTO;
import cn.rankin.data.api.product.dto.TrainingDTO;
import cn.rankin.data.api.product.vo.*;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@FeignClient(name = "${service.product.name}")
public interface ProductService {

    @RequestMapping(value = "/product", method = RequestMethod.GET)
    APIResult<Page<ProductVo>> search(@RequestParam Map<String, Object> searchDTO);

    @RequestMapping(value = "/product/{id}", method = RequestMethod.GET)
    APIResult getProduct(@PathVariable("id") String id);

    @RequestMapping(value = "/product/course", method = RequestMethod.PUT)
    APIResult<CourseVo> updateCourse(@RequestBody CourseDTO courseDTO);

    @RequestMapping(value = "/product/course", method = RequestMethod.POST)
    APIResult<CourseVo> createCourse(@RequestBody CourseDTO courseDTO);

    @RequestMapping(value = "/product/support", method = RequestMethod.PUT)
    APIResult<SupportVo> updateSupport(@RequestBody SupportDTO supportDTO);

    @RequestMapping(value = "/product/support", method = RequestMethod.POST)
    APIResult<SupportVo> createSupport(@RequestBody SupportDTO supportDTO);

    @RequestMapping(value = "/product/package", method = RequestMethod.POST)
    APIResult<PackageVo> createPackage(@RequestBody PackageDTO packageDTO);

    @RequestMapping(value = "/product/package", method = RequestMethod.PUT)
    APIResult<PackageVo> updatePackage(@RequestBody PackageDTO packageDTO);

    @RequestMapping(value = "/product/training", method = RequestMethod.POST)
    APIResult<TrainingItemVo> createTraining(@RequestBody TrainingDTO trainingDTO);

    @RequestMapping(value = "/product/training", method = RequestMethod.PUT)
    APIResult<TrainingItemVo> updateTraining(@RequestBody TrainingDTO trainingDTO);

    @RequestMapping(value = "/product/{id}", method = RequestMethod.DELETE)
    APIResult delete(@PathVariable("id") String id);

    @RequestMapping(value = "/product/ids", method = RequestMethod.GET)
    APIResult<List<ProductVo>> findProductByIds(@RequestParam("id") List<String> ids);
}
