package cn.rankin.productservice.service;

import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.enums.BaseOrderEnum;
import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.common.utils.util.JpaSortUtil;
import cn.rankin.common.utils.util.ListUtil;
import cn.rankin.data.api.product.dto.PosterDTO;
import cn.rankin.data.api.product.entity.Poster;
import cn.rankin.productservice.repository.PosterRepository;
import cn.rankin.productservice.utils.DTOConverter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import static cn.rankin.productservice.utils.DTOConverter.convert;

@Slf4j
@Service
public class PosterService {

    @Autowired
    private PosterRepository posterRepository;

    public List<Poster> findByIds(List<String> posterIds) {
        List<Poster> posterList = posterRepository.findByIds(posterIds);

        if (posterList == null || posterList.size() == 0) {
            return posterList;
        }

        Map<String, Poster> posterMap = ListUtil.convert(posterList, "id", Poster.class);
        List<Poster> sortPosterList = new ArrayList<>();
        posterIds.forEach( id -> {
            Poster poster = posterMap.get(id);
            if (poster != null) {
                sortPosterList.add(poster);
            }
        });

        return sortPosterList;
    }

    public Page<Poster> search(Poster poster, Integer pageNo, Integer pageSize, LinkedHashMap<String, BaseOrderEnum> sort) {
        Long count = posterRepository.count(poster);
        Page<Poster> page = new Page(count, pageNo, pageSize);

        if (count == 0) {
            return page;
        }

        List<Poster> posterList = posterRepository.find(poster, page.getStart(), pageSize, JpaSortUtil.sort(sort));
        page.setList(posterList);

        return page;
    }

    public Poster findById(String id) {
        Poster poster = posterRepository.find(id);
        return poster;
    }

/*    public boolean exists(String code) {
        Long count = posterRepository.countByCode(code);
        return count > 0L;
    }*/

    @Transactional
    public Poster create(PosterDTO posterDTO) {
        /*String code = lessonDTO.getCode();
        if (exists(code)) {
            return APIResult.error(APICode.ALREADY_EXISTS);
        }*/

        Poster poster = convert(posterDTO);
        Poster result = posterRepository.save(poster);

        return result;
    }

    @Transactional
    public Poster update(PosterDTO posterDTO) {
        Poster poster = DTOConverter.convert(posterDTO);
        Poster result = posterRepository.update(poster);

        return result;
    }

    @Transactional
    public Boolean delete(String id) {
        Integer count = posterRepository.deleteById(id);
        if (count > 0) {
            return true;
        }
        return false;
    }

}
